@@ -17,10 +17,10 @@
 #include <KEduVocLesson>
 
 /**
-  * Model for the tree of containers (lessons, word types).
-  * ReadonlyContainerModel is a read only tree model.
-  * @see ContainerModel for its subclass that includes more options.
-  */
+ * Model for the tree of containers (lessons, word types).
+ * ReadonlyContainerModel is a read only tree model.
+ * @see ContainerModel for its subclass that includes more options.
+ */
 
 class ReadonlyContainerModel : public QAbstractItemModel
 {
@@ -29,20 +29,21 @@ class ReadonlyContainerModel : public QAbstractItemModel
 public:
     explicit ReadonlyContainerModel(KEduVocContainer::EnumContainerType type, QObject *parent = 0);
 
-    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
-    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex &index, int role) const override;
+    Qt::ItemFlags flags(const QModelIndex &index) const override;
 
-    QModelIndex index(int row, int column,
-                              const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
 
-    QModelIndex index(KEduVocContainer* container) const;
+    QModelIndex index(KEduVocContainer *container) const;
 
-    QModelIndex parent(const QModelIndex &index) const Q_DECL_OVERRIDE;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    QModelIndex parent(const QModelIndex &index) const override;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
 
     KEduVocContainer::EnumContainerType containerType();
 
+    KEduVocDocument *document() const;
+
 public slots:
     /** Set the new source kvtml file
      * @param doc the new file */
@@ -54,5 +55,4 @@ protected:
     std::shared_ptr<KEduVocDocument> m_doc;
 };
 
-
 #endif
