@@ -13,18 +13,17 @@
 class Dashboard;
 class QToolButton;
 
-class ButtonDelegate
-    : public QStyledItemDelegate
+class ButtonDelegate : public QStyledItemDelegate
 {
     Q_OBJECT
 public:
     ButtonDelegate(QAbstractItemView *itemView, Dashboard *parent);
 
-    virtual ~ButtonDelegate();
+    ~ButtonDelegate() override;
 
-    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
     QModelIndex hoveredIndex() const;
 
@@ -40,4 +39,4 @@ private:
     QToolButton *m_editButton;
 };
 
-#endif //BUTTONDELEGATE_H
+#endif // BUTTONDELEGATE_H
